@@ -6,8 +6,8 @@
 ;; Author: Campbell Barton <ideasman42@gmail.com>
 
 ;; URL: https://codeberg.org/ideasman42/emacs-scroll-on-jump
-;; Package-Version: 20251126.514
-;; Package-Revision: ffb6fbfda84a
+;; Package-Version: 20260108.1309
+;; Package-Revision: 3e4e13fab04a
 ;; Package-Requires: ((emacs "26.2"))
 
 ;;; Commentary:
@@ -59,7 +59,7 @@
   :type 'boolean)
 
 (defcustom scroll-on-jump-curve 'smooth
-  "The the method scrolling is calculated."
+  "The method for calculating scrolling speed."
   :type
   '(choice (const :tag "Smooth in/out, starts & ends slow" smooth)
            (const :tag "Smooth in, starts slow" smooth-in)
@@ -67,16 +67,16 @@
            (const :tag "Linear" linear)))
 
 (defcustom scroll-on-jump-curve-power 3.0
-  "The strength of the curve (when set to linear).
+  "The strength of the curve (ignored when set to linear).
 A value of 1.0 is linear, values between 2 and 8 work well."
   :type 'float)
 
 (defcustom scroll-on-jump-mode-line-format nil
   "The `mode-line-format' to use or nil to leave the `mode-line-format' unchanged.
 
-This can be useful to use a simplified or event disabling the mode-line
+This can be useful for simplifying or even disabling the mode-line
 while scrolling, as a complex mode-line can interfere with smooth scrolling."
-  :type '(choice (const nil) string))
+  :type '(choice (const :tag "Unchanged" nil) sexp))
 
 
 ;; ---------------------------------------------------------------------------
@@ -97,12 +97,13 @@ Move LINES in WINDOW, when ALSO-MOVE-POINT is set, the point is moved too."
                     t))
 
 ;; Per-line Scroll.
-;; return remainder of lines to scroll (matching forward-line).
 (defun scroll-on-jump--scroll-by-lines (window lines also-move-point)
-  "Line based scroll that optionally move the point.
+  "Line based scroll that optionally moves the point.
 Argument WINDOW The window to scroll.
 Argument LINES The number of lines to scroll (signed).
-Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
+Argument ALSO-MOVE-POINT When non-nil, move the POINT as well.
+
+Return remainder of lines to scroll (matching `forward-line')."
   (declare (important-return-value t))
   (let ((lines-remainder 0))
     (when also-move-point
@@ -121,15 +122,15 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
           (forward-line (- lines-remainder)))))
     lines-remainder))
 
-
 ;; Per-pixel Scroll,
-;; return remainder of lines to scroll (matching forward-line).
 (defun scroll-on-jump--scroll-by-pixels (window char-height delta-px also-move-point)
-  "Line based scroll that optionally move the point.
+  "Pixel based scroll that optionally moves the point.
 Argument WINDOW The window to scroll.
 Argument CHAR-HEIGHT The result of `frame-char-height'.
 Argument DELTA-PX The number of pixels to scroll (signed).
-Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
+Argument ALSO-MOVE-POINT When non-nil, move the POINT as well.
+
+Return remainder of lines to scroll (matching `forward-line')."
   (declare (important-return-value nil))
   (cond
    ((< delta-px 0)
@@ -182,12 +183,11 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
 
 (defsubst scroll-on-jump--set-mark-from-point ()
   "Convenience function to set the mark to the point."
-  (let ((m (mark-marker)))
-    ;; This should practically never be nil,
-    ;; although it's not impossible the mark is somehow cleared while drawing,
-    ;; in this case, doing nothing is OK.
-    (when m
-      (set-marker m (point)))))
+  ;; This should practically never be nil,
+  ;; although it's not impossible the mark is somehow cleared while drawing,
+  ;; in this case, doing nothing is OK.
+  (when-let* ((m (mark-marker)))
+    (set-marker m (point))))
 
 (defmacro scroll-on-jump--save-mark-conditionally (test-condition &rest body)
   "Run BODY, restoring the marks original location when TEST-CONDITION is non-nil."
@@ -202,16 +202,15 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
                 ,@body)
          ;; Unlikely but possible the mark no longer exists.
          (when ,mk-pos
-           (let ((mk (mark-marker)))
-             (when mk
-               (set-marker mk ,mk-pos))))))))
+           (when-let* ((mk (mark-marker)))
+             (set-marker mk ,mk-pos)))))))
 
 
 ;; ---------------------------------------------------------------------------
 ;; Internal Interpolation Functions
 
 (defsubst scroll-on-jump--interp-linear-impl (a b factor)
-  "Internal macro for to blend A, B by FACTOR."
+  "Blend A toward B by FACTOR."
   (+ a (* (- b a) factor)))
 
 (defun scroll-on-jump--interp-linear (a b factor)
@@ -225,7 +224,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
   (scroll-on-jump--interp-linear-impl a b (expt factor scroll-on-jump-curve-power)))
 
 (defun scroll-on-jump--interp-ease-out (a b factor)
-  "Blend FACTOR between A and B using ease-in curvature."
+  "Blend FACTOR between A and B using ease-out curvature."
   (declare (important-return-value t))
   (scroll-on-jump--interp-linear-impl
    a b (- 1.0 (expt (- 1.0 factor) scroll-on-jump-curve-power))))
@@ -265,7 +264,7 @@ Argument ALSO-MOVE-POINT When non-nil, move the POINT as well."
 ;; ---------------------------------------------------------------------------
 ;; Internal Logic
 
-(defun scroll-on-jump--immediate-scroll (window lines-scroll _dir)
+(defun scroll-on-jump--immediate-scroll (window lines-scroll)
   "Non animated scroll for WINDOW to move LINES-SCROLL."
   (declare (important-return-value nil))
   (scroll-on-jump--scroll-by-lines-simple window lines-scroll nil))
@@ -276,7 +275,7 @@ Moving the point when ALSO-MOVE-POINT is set."
   (declare (important-return-value nil))
   (let ((time-init (current-time))
         ;; For motion less than a window, scale down the time allowed.
-        ;; This means moving a short distance wont be given the full time.
+        ;; This means moving a short distance won't be given the full time.
         (time-limit
          (* scroll-on-jump-duration
             (min 1.0 (/ (float (abs lines-scroll)) (float (window-body-height window))))))
@@ -350,7 +349,7 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
   (declare (important-return-value nil))
   (let ((time-init (current-time))
         ;; For motion less than a window, scale down the time allowed.
-        ;; This means moving a short distance wont be given the full time.
+        ;; This means moving a short distance won't be given the full time.
         (time-limit
          (* scroll-on-jump-duration
             (min 1.0 (/ (float (abs lines-scroll)) (float (window-body-height window))))))
@@ -445,7 +444,7 @@ Argument ALSO-MOVE-POINT moves the point while scrolling."
 
 (defun scroll-on-jump--scroll-animated (window lines-scroll dir also-move-point)
   "Perform an animated scroll.
-see `scroll-on-jump--scroll-impl' for doc-strings for WINDOW, LINES-SCROLL, DIR & ALSO-MOVE-POINT."
+See `scroll-on-jump--scroll-impl' for doc-strings for WINDOW, LINES-SCROLL, DIR & ALSO-MOVE-POINT."
   (declare (important-return-value nil))
   (cond
    ;; Use pixel scrolling.
@@ -469,7 +468,7 @@ Moving the point when ALSO-MOVE-POINT is set."
   (cond
    ;; No animation.
    ((zerop scroll-on-jump-duration)
-    (scroll-on-jump--immediate-scroll window lines-scroll dir))
+    (scroll-on-jump--immediate-scroll window lines-scroll))
    ;; Animated scroll.
    (scroll-on-jump-mode-line-format
     (prog1 (let ((mode-line-format scroll-on-jump-mode-line-format))
@@ -575,14 +574,14 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
              ;; this has the advantage that we could get the resulting cursor location
              ;; even in the case of an error.
              ;; However - this makes troubleshooting problems considerably more difficult.
-             ;; As it wont show the full back-trace, only the error message.
+             ;; As it won't show the full back-trace, only the error message.
              ;; So don't prioritize correct jumping in the case of errors and assume errors
              ;; are not something that happen after cursor motion.
              (scroll-on-jump--outer-scoped-mark point-orig point-prev
                (scroll-on-jump--inner-scoped-mark (window-start window) window-start-prev
                  (scroll-on-jump--inner-scoped-mark point-orig point-next
                    ;; Run the main body of this function.
-                   ;; It's important the result if returned (hence the `prog1' use).
+                   ;; It's important the result is returned (hence the `prog1' use).
                    (funcall body-fn)))))
 
       ;; Quiet unused argument warning.
@@ -644,7 +643,7 @@ Argument USE-WINDOW-START detects window scrolling when non-nil."
 
 ;;;###autoload
 (defun scroll-on-jump-interactive (fn)
-  "Macro that wraps interactive call to function FN.
+  "Function that wraps interactive call to function FN.
 
 Use if you want to use `scroll-on-jump' for a single `key-binding',
 without changing behavior anywhere else."
@@ -685,7 +684,7 @@ This calls (calling OLD-FN with ARGS)."
 
 ;;;###autoload
 (defun scroll-on-jump-with-scroll-interactive (fn)
-  "Macro that wraps interactive call to function FN.
+  "Function that wraps interactive call to function FN.
 
 Use if you want to use `scroll-on-jump-with-scroll' for a single `key-binding',
 without changing behavior anywhere else."
